skiptools
=========

.. automodule:: abjad.tools.skiptools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.skiptools.Skip.Skip.Skip

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.skiptools.make_repeated_skips_from_time_signatures.make_repeated_skips_from_time_signatures
      ~abjad.tools.skiptools.make_skips_with_multiplied_durations.make_skips_with_multiplied_durations
